==> pygame_1.9.6+dfsg.orig.tar.xz: pygame-1.9.6/src_c/doc/surfarray_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMESURFARRAY "pygame module for accessing surface pixel data using array interfaces"
#define DOC_PYGAMESURFARRAYARRAY2D "array2d(Surface) -> array\nCopy pixels into a 2d array"
#define DOC_PYGAMESURFARRAYPIXELS2D "pixels2d(Surface) -> array\nReference pixels into a 2d array"
#define DOC_PYGAMESURFARRAYARRAY3D "array3d(Surface) -> array\nCopy pixels into a 3d array"
#define DOC_PYGAMESURFARRAYPIXELS3D "pixels3d(Surface) -> array\nReference pixels into a 3d array"
#define DOC_PYGAMESURFARRAYARRAYALPHA "array_alpha(Surface) -> array\nCopy pixel alphas into a 2d array"
#define DOC_PYGAMESURFARRAYPIXELSALPHA "pixels_alpha(Surface) -> array\nReference pixel alphas into a 2d array"
#define DOC_PYGAMESURFARRAYPIXELSRED "pixels_red (Surface) -> array\nReference pixel red into a 2d array."
#define DOC_PYGAMESURFARRAYPIXELSGREEN "pixels_green (Surface) -> array\nReference pixel green into a 2d array."
#define DOC_PYGAMESURFARRAYPIXELSBLUE "pixels_blue (Surface) -> array\nReference pixel blue into a 2d array."
#define DOC_PYGAMESURFARRAYARRAYCOLORKEY "array_colorkey(Surface) -> array\nCopy the colorkey values into a 2d array"
#define DOC_PYGAMESURFARRAYMAKESURFACE "make_surface(array) -> Surface\nCopy an array to a new surface"
#define DOC_PYGAMESURFARRAYBLITARRAY "blit_array(Surface, array) -> None\nBlit directly from a array values"
#define DOC_PYGAMESURFARRAYMAPARRAY "map_array(Surface, array3d) -> array2d\nMap a 3d array into a 2d array"
#define DOC_PYGAMESURFARRAYUSEARRAYTYPE "use_arraytype (arraytype) -> None\nSets the array system to be used for surface arrays"
#define DOC_PYGAMESURFARRAYGETARRAYTYPE "get_arraytype () -> str\nGets the currently active array type."
#define DOC_PYGAMESURFARRAYGETARRAYTYPES "get_arraytypes () -> tuple\nGets the array system types currently supported."


/* Docs in a comment... slightly easier to read. */

/*

pygame.surfarray
pygame module for accessing surface pixel data using array interfaces

pygame.surfarray.array2d
 array2d(Surface) -> array
Copy pixels into a 2d array

pygame.surfarray.pixels2d
 pixels2d(Surface) -> array
Reference pixels into a 2d array

pygame.surfarray.array3d
 array3d(Surface) -> array
Copy pixels into a 3d array

pygame.surfarray.pixels3d
 pixels3d(Surface) -> array
Reference pixels into a 3d array

pygame.surfarray.array_alpha
 array_alpha(Surface) -> array
Copy pixel alphas into a 2d array

pygame.surfarray.pixels_alpha
 pixels_alpha(Surface) -> array
Reference pixel alphas into a 2d array

pygame.surfarray.pixels_red
 pixels_red (Surface) -> array
Reference pixel red into a 2d array.

pygame.surfarray.pixels_green
 pixels_green (Surface) -> array
Reference pixel green into a 2d array.

pygame.surfarray.pixels_blue
 pixels_blue (Surface) -> array
Reference pixel blue into a 2d array.

pygame.surfarray.array_colorkey
 array_colorkey(Surface) -> array
Copy the colorkey values into a 2d array

pygame.surfarray.make_surface
 make_surface(array) -> Surface
Copy an array to a new surface

pygame.surfarray.blit_array
 blit_array(Surface, array) -> None
Blit directly from a array values

pygame.surfarray.map_array
 map_array(Surface, array3d) -> array2d
Map a 3d array into a 2d array

pygame.surfarray.use_arraytype
 use_arraytype (arraytype) -> None
Sets the array system to be used for surface arrays

pygame.surfarray.get_arraytype
 get_arraytype () -> str
Gets the currently active array type.

pygame.surfarray.get_arraytypes
 get_arraytypes () -> tuple
Gets the array system types currently supported.

*/

==> pygame_2.1.2+dfsg.orig.tar.xz: pygame-2.1.2/src_c/doc/surfarray_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMESURFARRAY "pygame module for accessing surface pixel data using array interfaces"
#define DOC_PYGAMESURFARRAYARRAY2D "array2d(Surface) -> array\nCopy pixels into a 2d array"
#define DOC_PYGAMESURFARRAYPIXELS2D "pixels2d(Surface) -> array\nReference pixels into a 2d array"
#define DOC_PYGAMESURFARRAYARRAY3D "array3d(Surface) -> array\nCopy pixels into a 3d array"
#define DOC_PYGAMESURFARRAYPIXELS3D "pixels3d(Surface) -> array\nReference pixels into a 3d array"
#define DOC_PYGAMESURFARRAYARRAYALPHA "array_alpha(Surface) -> array\nCopy pixel alphas into a 2d array"
#define DOC_PYGAMESURFARRAYPIXELSALPHA "pixels_alpha(Surface) -> array\nReference pixel alphas into a 2d array"
#define DOC_PYGAMESURFARRAYARRAYRED "array_red(Surface) -> array\nCopy red pixels into a 2d array"
#define DOC_PYGAMESURFARRAYPIXELSRED "pixels_red (Surface) -> array\nReference pixel red into a 2d array."
#define DOC_PYGAMESURFARRAYARRAYGREEN "array_green(Surface) -> array\nCopy green pixels into a 2d array"
#define DOC_PYGAMESURFARRAYPIXELSGREEN "pixels_green (Surface) -> array\nReference pixel green into a 2d array."
#define DOC_PYGAMESURFARRAYARRAYBLUE "array_blue(Surface) -> array\nCopy blue pixels into a 2d array"
#define DOC_PYGAMESURFARRAYPIXELSBLUE "pixels_blue (Surface) -> array\nReference pixel blue into a 2d array."
#define DOC_PYGAMESURFARRAYARRAYCOLORKEY "array_colorkey(Surface) -> array\nCopy the colorkey values into a 2d array"
#define DOC_PYGAMESURFARRAYMAKESURFACE "make_surface(array) -> Surface\nCopy an array to a new surface"
#define DOC_PYGAMESURFARRAYBLITARRAY "blit_array(Surface, array) -> None\nBlit directly from a array values"
#define DOC_PYGAMESURFARRAYMAPARRAY "map_array(Surface, array3d) -> array2d\nMap a 3d array into a 2d array"
#define DOC_PYGAMESURFARRAYUSEARRAYTYPE "use_arraytype (arraytype) -> None\nSets the array system to be used for surface arrays"
#define DOC_PYGAMESURFARRAYGETARRAYTYPE "get_arraytype () -> str\nGets the currently active array type."
#define DOC_PYGAMESURFARRAYGETARRAYTYPES "get_arraytypes () -> tuple\nGets the array system types currently supported."


/* Docs in a comment... slightly easier to read. */

/*

pygame.surfarray
pygame module for accessing surface pixel data using array interfaces

pygame.surfarray.array2d
 array2d(Surface) -> array
Copy pixels into a 2d array

pygame.surfarray.pixels2d
 pixels2d(Surface) -> array
Reference pixels into a 2d array

pygame.surfarray.array3d
 array3d(Surface) -> array
Copy pixels into a 3d array

pygame.surfarray.pixels3d
 pixels3d(Surface) -> array
Reference pixels into a 3d array

pygame.surfarray.array_alpha
 array_alpha(Surface) -> array
Copy pixel alphas into a 2d array

pygame.surfarray.pixels_alpha
 pixels_alpha(Surface) -> array
Reference pixel alphas into a 2d array

pygame.surfarray.array_red
 array_red(Surface) -> array
Copy red pixels into a 2d array

pygame.surfarray.pixels_red
 pixels_red (Surface) -> array
Reference pixel red into a 2d array.

pygame.surfarray.array_green
 array_green(Surface) -> array
Copy green pixels into a 2d array

pygame.surfarray.pixels_green
 pixels_green (Surface) -> array
Reference pixel green into a 2d array.

pygame.surfarray.array_blue
 array_blue(Surface) -> array
Copy blue pixels into a 2d array

pygame.surfarray.pixels_blue
 pixels_blue (Surface) -> array
Reference pixel blue into a 2d array.

pygame.surfarray.array_colorkey
 array_colorkey(Surface) -> array
Copy the colorkey values into a 2d array

pygame.surfarray.make_surface
 make_surface(array) -> Surface
Copy an array to a new surface

pygame.surfarray.blit_array
 blit_array(Surface, array) -> None
Blit directly from a array values

pygame.surfarray.map_array
 map_array(Surface, array3d) -> array2d
Map a 3d array into a 2d array

pygame.surfarray.use_arraytype
 use_arraytype (arraytype) -> None
Sets the array system to be used for surface arrays

pygame.surfarray.get_arraytype
 get_arraytype () -> str
Gets the currently active array type.

pygame.surfarray.get_arraytypes
 get_arraytypes () -> tuple
Gets the array system types currently supported.

*/
